# yfinance_fixed

## Description
This package was developed to streamline fixing SSL errors encountered while using yfinance.

## Usage
import the package using the command:
```python
import yfinance_fixed as yfx
```

To use it, run:
```python
yfx.req(ticker)
```

You can also use the command with start and end date parameters if you wish:
```python
yfx.req(ticker, start='YYYY-MM-DD', end='YYYY-MM-DD')
```

For suggestions or bugs, please use the **issues** page or submit a **pull request**.
